@@ -29,8 +29,6 @@
 # 1050 Brussels, Belgium                     http://iridia.ulb.ac.be/~mbiro #
 # ========================================================================= #
 
-# $Id: example-wrapper.R,v 1.10 2004/04/01 08:56:31 mbiro Exp $ #
-
 race.init<-function(){
   # Load libraries and data
   library(nnet) 
@@ -46,8 +44,8 @@ race.init<-function(){
   set.seed(0)
   smpl<-sample(n)  
   # Restore the random seed
-  if(exists("save",inherits=FALSE))
-    assign(".Random.seed",save,envir=globalenv())
+  if(exists("save.seed",inherits=FALSE))
+    assign(".Random.seed",save.seed,envir=globalenv())
   else
     rm(".Random.seed",envir=globalenv())
   # As if nothing appened...
